@@ -5,7 +5,7 @@ DEBUG = True
 DATABASES = {
     'default': {
         'ENGINE': 'django.db.backends.sqlite3',
-        'NAME': '/tmp/django-csvimport-test.db',
+        'NAME': 'django-csvimport-test.db',
         'USER': '',     # Not used with sqlite3.
         'PASSWORD': '', # Not used with sqlite3.
         'HOST': '',     # Set to empty string for localhost. 
@@ -13,8 +13,11 @@ DATABASES = {
     }
 }
 
-MEDIA_ROOT = '/tmp'
+MEDIA_ROOT = ''
 MEDIA_URL = '/files/'
+# URL prefix for static files.
+# Example: "http://media.lawrence.com/static/"
+STATIC_URL = '/static/'
 
 INSTALLED_APPS = (
     # Add csvimport app itself and the tests models
@@ -35,6 +38,6 @@ ROOT_URLCONF = 'csvimport.tests.urls'
 SECRET_KEY = 't_8)4w_csvimport_not_secret_test_key_7^b*s%w$zrud'
 
 TEMPLATE_LOADERS = (
-    'django.template.loaders.filesystem.load_template_source',
-    'django.template.loaders.app_directories.load_template_source',
+    'django.template.loaders.filesystem.Loader',
+    'django.template.loaders.app_directories.Loader',
 )
